local addonName, addon = ...
addon.L = addon.L or {} --setup localization
local L = setmetatable(addon.L, {__index = function(t,i) return i end} )
local LSM = LibStub("LibSharedMedia-3.0")

local defaults = {
	profile = {
		enabled = true,
		font = "Friz Quadrata TT",
		fontSize = 15,
		anchorFrame = "CENTER",
		anchorParent = "CENTER",
		xOffset = 0,
		yOffset = 0,
	},
}

local optionsTable = {
    name = addonName,
    handler = addon,
    type = 'group',
    args = {
		enable = {
			name = L.Enable,
			desc = L["Enable/disable the addon."],
			type = 'toggle',
			order = 1,
			set = function(_, enabled)
				addon.db.profile.enabled = enabled
				if enabled then
					addon:Enable()
				else
					addon:Disable()
				end
			end,
			get = function() return addon.db.profile.enabled end,
		},
		options = {
			name = L['Options'],
			desc = L['Setup options here.'],
			type = 'group',
			order = 2,
			args = {
				font = {
					type = 'select',
					order = 1,
					dialogControl = 'LSM30_Font',
					name = L['Font'],
					desc = L['Select a font.'],
					values = LSM:HashTable("font"),
					get = function()
						return addon.db.profile.font
					end,
					set = function(self,key)
						addon.db.profile.font = key
						addon:ApplyAllOptions()
					end,
				},
				fontSize = {
					type = 'input',
					order = 2,
					name = L['Font Size'],
					desc = L['Set the font size.'],
					set = function(_, value)
						addon.db.profile.fontSize = tonumber(value)
						addon:ApplyAllOptions()
					end,
					get = function() 
						return tostring(addon.db.profile.fontSize)
					end,
				},
			},
		},
    },
}

function addon:SetupConfig()
	self.db = LibStub("AceDB-3.0"):New("ShieldBarrierTrackerDB", defaults)
	
	optionsTable.args.profile = LibStub("AceDBOptions-3.0"):GetOptionsTable(self.db) --add profile GUI
	self.db.RegisterCallback(self, "OnProfileChanged", "ApplyAllOptions")
	self.db.RegisterCallback(self, "OnProfileCopied", "ApplyAllOptions")
	self.db.RegisterCallback(self, "OnProfileReset", "ApplyAllOptions")
	
	LibStub("AceConfig-3.0"):RegisterOptionsTable(addonName, optionsTable)
	LibStub("AceConfigDialog-3.0"):AddToBlizOptions(addonName)
end